.. Copyright NTESS. See COPYRIGHT file for details.

   SPDX-License-Identifier: MIT



.. _canary_cmake.ctest:

ctest
=====

.. automodule:: canary_cmake.ctest
   :members:
   :undoc-members:
   :show-inheritance:
